# Changelog

## 0.5.0 (2025-12-31)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/TEKIMAX/tekimax-python/compare/v0.4.0...v0.5.0)

### Features

* Update OpenAPI spec from architecture-engine-api ([0b100ce](https://github.com/TEKIMAX/tekimax-python/commit/0b100ce5e618ebd7edb2319623a2b32b906473cb))


### Chores

* update SDK settings ([995c44f](https://github.com/TEKIMAX/tekimax-python/commit/995c44f4fe0b4e105d5cf18d3a1d8f8ae1f7d4eb))

## 0.4.0 (2025-12-30)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/TEKIMAX/tekimax-python/compare/v0.3.0...v0.4.0)

### Features

* Update OpenAPI spec from architecture-engine-api ([6a70dfe](https://github.com/TEKIMAX/tekimax-python/commit/6a70dfe4405d12fb2946dd45df30ee262813a76d))


### Chores

* update SDK settings ([df24cf9](https://github.com/TEKIMAX/tekimax-python/commit/df24cf98408caafb04bc7a2190cace0e3480b051))

## 0.3.0 (2025-12-30)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/TEKIMAX/tekimax-python/compare/v0.2.0...v0.3.0)

### Features

* Update OpenAPI spec from architecture-engine-api ([8867ae9](https://github.com/TEKIMAX/tekimax-python/commit/8867ae94c391546902ad152252f510ff31477eb0))

## 0.2.0 (2025-12-30)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/TEKIMAX/tekimax-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([069f677](https://github.com/TEKIMAX/tekimax-python/commit/069f6772552c7bad25ce550967563efc83a88132))


### Chores

* update SDK settings ([b96e10b](https://github.com/TEKIMAX/tekimax-python/commit/b96e10bfb3b7cd5aaa90462e46e1682b66326637))
* update SDK settings ([fe6b3d1](https://github.com/TEKIMAX/tekimax-python/commit/fe6b3d16ed8140b4ce66dac49783c3fabe9de849))

## 0.1.0 (2025-12-30)

Full Changelog: [v0.0.2...v0.1.0](https://github.com/TEKIMAX/tekimax-python/compare/v0.0.2...v0.1.0)

### Features

* **api:** manual updates ([d4819fc](https://github.com/TEKIMAX/tekimax-python/commit/d4819fc50c5c7be0420758985eb0f6247b3eeeb4))

## 0.0.2 (2025-12-30)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/TEKIMAX/tekimax-python/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([9bc93d8](https://github.com/TEKIMAX/tekimax-python/commit/9bc93d830068a718f765c500e9130c00862b2f18))
* update SDK settings ([27de092](https://github.com/TEKIMAX/tekimax-python/commit/27de09294d3a1adc072b71b6efe5f2c4bae538c0))
